/* 
 * Browshot API
 *
 * Take screenshots of any website in real time
 *
 * OpenAPI spec version: 1.16.0
 * Contact: support@browshot.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */

package swagger

import (
	"net/url"
	"strings"
	"encoding/json"
)

type ScreenshotApi struct {
	Configuration *Configuration
}

func NewScreenshotApi() *ScreenshotApi {
	configuration := NewConfiguration()
	return &ScreenshotApi{
		Configuration: configuration,
	}
}

func NewScreenshotApiWithBasePath(basePath string) *ScreenshotApi {
	configuration := NewConfiguration()
	configuration.BasePath = basePath

	return &ScreenshotApi{
		Configuration: configuration,
	}
}

/**
 * Request a screenshot
 * Screenshots requests to private and shared instances require a positive balance.  *IMPORTANT*: Remember that you can only do 100 free screenshots per month. To used a premium instance, use instance_id&#x3D;65 for example. 
 *
 * @param url URL of the page to get a screenshot for
 * @param instanceId instance ID to use
 * @param size screenshot size - \&quot;screen\&quot; (default) or \&quot;page\&quot;
 * @param cache use a previous screenshot (same URL, same instance) if it was done within &lt;cache_value&gt; seconds. The default value is 24hours. Specify cache&#x3D;0 if you want a new screenshot.
 * @param delay number of seconds to wait after the page has loaded. This is used to let JavaScript run longer before taking the screenshot. Use delay&#x3D;0 to take screenshots faster.
 * @param flashDelay number of seconds to wait after the page has loaded if Flash elements are present. Use flash_delay&#x3D;0 to take screenshots faster.
 * @param screenWidth width of the browser window. For desktop browsers only.
 * @param screenHeight height of the browser window. For desktop browsers only. (Note: full-page screenshots can have a height of up to 15,000px)
 * @param priority assign priority to the screenshot (for private instances only)
 * @param referer use a custom referrer header - paid screenshots only
 * @param postData send a POST requests with post_data, useful for filling out forms - paid screenshots only
 * @param cookie set a cookie for the URL requested (see Custom POST Data, Referer and Cookie) Cookies should be separated by a ; - paid screenshots only
 * @param script URL of javascript file to execute after the page load event
 * @param details level of information available with screenshot/info
 * @param html saves the HTML of the rendered page which can be retrieved by the API call screenshot/html. This feature costs *1 credit* per screenshot.
 * @param maxWait maximum number of seconds to wait before triggering the PageLoad event. Note that delay will still be used. (default: 0 &#x3D; disabled)
 * @param headers any custom HTTP headers. (Not supported with Internet Explorer)
 * @param shots take multiple screenshots of the same page. This costs 1 additional credit for every 2 additional screenshots.
 * @param shotInterval number of seconds between 2 screenshots
 * @param hosting hosting option - s3 or browshot
 * @param hostingHeight maximum height of the thumbnail to host
 * @param hostingWidth maximum height of the thumbnail to host
 * @param hostingScale scale of the thumbnail to host
 * @param hostingBucket S3 bucket to upload the screenshot or thumbnail (required for S3)
 * @param hostingFile file name to use (for S3 only)
 * @param hostingHeaders list of headers to add to the S3 object (for S3 only)
 * @return *Screenshot
 */
func (a ScreenshotApi) ScreenshotCreateGet(url string, instanceId int32, size string, cache int32, delay int32, flashDelay int32, screenWidth int32, screenHeight int32, priority int32, referer string, postData string, cookie string, script string, details int32, html int32, maxWait int32, headers string, shots int32, shotInterval int32, hosting string, hostingHeight int32, hostingWidth int32, hostingScale float32, hostingBucket string, hostingFile string, hostingHeaders string) (*Screenshot, *APIResponse, error) {

	var localVarHttpMethod = strings.ToUpper("Get")
	// create path and map variables
	localVarPath := a.Configuration.BasePath + "/screenshot/create"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := make(map[string]string)
	var localVarPostBody interface{}
	var localVarFileName string
	var localVarFileBytes []byte
	// authentication '(apiKeyQuery)' required
	// set key with prefix in query string
	localVarQueryParams["key"] =  a.Configuration.GetAPIKeyWithPrefix("key")
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		localVarHeaderParams[key] = a.Configuration.DefaultHeader[key]
	}
	localVarQueryParams.Add("url", a.Configuration.APIClient.ParameterToString(url, ""))
	localVarQueryParams.Add("instance_id", a.Configuration.APIClient.ParameterToString(instanceId, ""))
	localVarQueryParams.Add("size", a.Configuration.APIClient.ParameterToString(size, ""))
	localVarQueryParams.Add("cache", a.Configuration.APIClient.ParameterToString(cache, ""))
	localVarQueryParams.Add("delay", a.Configuration.APIClient.ParameterToString(delay, ""))
	localVarQueryParams.Add("flash_delay", a.Configuration.APIClient.ParameterToString(flashDelay, ""))
	localVarQueryParams.Add("screen_width", a.Configuration.APIClient.ParameterToString(screenWidth, ""))
	localVarQueryParams.Add("screen_height", a.Configuration.APIClient.ParameterToString(screenHeight, ""))
	localVarQueryParams.Add("priority", a.Configuration.APIClient.ParameterToString(priority, ""))
	localVarQueryParams.Add("referer", a.Configuration.APIClient.ParameterToString(referer, ""))
	localVarQueryParams.Add("post_data", a.Configuration.APIClient.ParameterToString(postData, ""))
	localVarQueryParams.Add("cookie", a.Configuration.APIClient.ParameterToString(cookie, ""))
	localVarQueryParams.Add("script", a.Configuration.APIClient.ParameterToString(script, ""))
	localVarQueryParams.Add("details", a.Configuration.APIClient.ParameterToString(details, ""))
	localVarQueryParams.Add("html", a.Configuration.APIClient.ParameterToString(html, ""))
	localVarQueryParams.Add("max_wait", a.Configuration.APIClient.ParameterToString(maxWait, ""))
	localVarQueryParams.Add("headers", a.Configuration.APIClient.ParameterToString(headers, ""))
	localVarQueryParams.Add("shots", a.Configuration.APIClient.ParameterToString(shots, ""))
	localVarQueryParams.Add("shot_interval", a.Configuration.APIClient.ParameterToString(shotInterval, ""))
	localVarQueryParams.Add("hosting", a.Configuration.APIClient.ParameterToString(hosting, ""))
	localVarQueryParams.Add("hosting_height", a.Configuration.APIClient.ParameterToString(hostingHeight, ""))
	localVarQueryParams.Add("hosting_width", a.Configuration.APIClient.ParameterToString(hostingWidth, ""))
	localVarQueryParams.Add("hosting_scale", a.Configuration.APIClient.ParameterToString(hostingScale, ""))
	localVarQueryParams.Add("hosting_bucket", a.Configuration.APIClient.ParameterToString(hostingBucket, ""))
	localVarQueryParams.Add("hosting_file", a.Configuration.APIClient.ParameterToString(hostingFile, ""))
	localVarQueryParams.Add("hosting_headers", a.Configuration.APIClient.ParameterToString(hostingHeaders, ""))

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
		}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new(Screenshot)
	localVarHttpResponse, err := a.Configuration.APIClient.CallAPI(localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)

	var localVarURL, _ = url.Parse(localVarPath)
	localVarURL.RawQuery = localVarQueryParams.Encode()
	var localVarAPIResponse = &APIResponse{Operation: "ScreenshotCreateGet", Method: localVarHttpMethod, RequestURL: localVarURL.String()}
	if localVarHttpResponse != nil {
		localVarAPIResponse.Response = localVarHttpResponse.RawResponse
		localVarAPIResponse.Payload = localVarHttpResponse.Body()
	}

	if err != nil {
		return successPayload, localVarAPIResponse, err
	}
	err = json.Unmarshal(localVarHttpResponse.Body(), &successPayload)
	return successPayload, localVarAPIResponse, err
}

/**
 * Delete screenshot data
 * You can delete details of your screenshots to remove any confidential information. 
 *
 * @param id screenshot ID
 * @param data data to remove. You can specify multiple of them (separated by a ,): *image* (image files), *url* (url requested), *metadata* (time added, time finished, post data, cookie and referer used for the screenshot), *all* (all data and files) 
 * @return []ScreenshotShort
 */
func (a ScreenshotApi) ScreenshotDeleteGet(id int32, data string) ([]ScreenshotShort, *APIResponse, error) {

	var localVarHttpMethod = strings.ToUpper("Get")
	// create path and map variables
	localVarPath := a.Configuration.BasePath + "/screenshot/delete"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := make(map[string]string)
	var localVarPostBody interface{}
	var localVarFileName string
	var localVarFileBytes []byte
	// authentication '(apiKeyQuery)' required
	// set key with prefix in query string
	localVarQueryParams["key"] =  a.Configuration.GetAPIKeyWithPrefix("key")
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		localVarHeaderParams[key] = a.Configuration.DefaultHeader[key]
	}
	localVarQueryParams.Add("id", a.Configuration.APIClient.ParameterToString(id, ""))
	localVarQueryParams.Add("data", a.Configuration.APIClient.ParameterToString(data, ""))

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
		}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new([]ScreenshotShort)
	localVarHttpResponse, err := a.Configuration.APIClient.CallAPI(localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)

	var localVarURL, _ = url.Parse(localVarPath)
	localVarURL.RawQuery = localVarQueryParams.Encode()
	var localVarAPIResponse = &APIResponse{Operation: "ScreenshotDeleteGet", Method: localVarHttpMethod, RequestURL: localVarURL.String()}
	if localVarHttpResponse != nil {
		localVarAPIResponse.Response = localVarHttpResponse.RawResponse
		localVarAPIResponse.Payload = localVarHttpResponse.Body()
	}

	if err != nil {
		return *successPayload, localVarAPIResponse, err
	}
	err = json.Unmarshal(localVarHttpResponse.Body(), &successPayload)
	return *successPayload, localVarAPIResponse, err
}

/**
 * Host thumbnails on your own S3 account or on Browshot.
 * You can host screenshots and thumbnails on your own S3 account or on Browshot.
 *
 * @param id screenshot ID
 * @param hosting hosting option: s3 or browshot
 * @param width width of the thumbnail
 * @param height height of the thumbnail
 * @param scale scale of the thumbnail
 * @param bucket S3 bucket to upload the screenshot or thumbnail - required with hosting&#x3D;s3
 * @param file file name to use - optional, used with hosting&#x3D;s3
 * @param headers HTTP headers to add to your S3 object - optional, used with hosting&#x3D;s3
 * @return []ScreenshotHost
 */
func (a ScreenshotApi) ScreenshotHostGet(id int32, hosting string, width int32, height int32, scale float64, bucket string, file string, headers string) ([]ScreenshotHost, *APIResponse, error) {

	var localVarHttpMethod = strings.ToUpper("Get")
	// create path and map variables
	localVarPath := a.Configuration.BasePath + "/screenshot/host"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := make(map[string]string)
	var localVarPostBody interface{}
	var localVarFileName string
	var localVarFileBytes []byte
	// authentication '(apiKeyQuery)' required
	// set key with prefix in query string
	localVarQueryParams["key"] =  a.Configuration.GetAPIKeyWithPrefix("key")
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		localVarHeaderParams[key] = a.Configuration.DefaultHeader[key]
	}
	localVarQueryParams.Add("id", a.Configuration.APIClient.ParameterToString(id, ""))
	localVarQueryParams.Add("hosting", a.Configuration.APIClient.ParameterToString(hosting, ""))
	localVarQueryParams.Add("width", a.Configuration.APIClient.ParameterToString(width, ""))
	localVarQueryParams.Add("height", a.Configuration.APIClient.ParameterToString(height, ""))
	localVarQueryParams.Add("scale", a.Configuration.APIClient.ParameterToString(scale, ""))
	localVarQueryParams.Add("bucket", a.Configuration.APIClient.ParameterToString(bucket, ""))
	localVarQueryParams.Add("file", a.Configuration.APIClient.ParameterToString(file, ""))
	localVarQueryParams.Add("headers", a.Configuration.APIClient.ParameterToString(headers, ""))

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
		}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new([]ScreenshotHost)
	localVarHttpResponse, err := a.Configuration.APIClient.CallAPI(localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)

	var localVarURL, _ = url.Parse(localVarPath)
	localVarURL.RawQuery = localVarQueryParams.Encode()
	var localVarAPIResponse = &APIResponse{Operation: "ScreenshotHostGet", Method: localVarHttpMethod, RequestURL: localVarURL.String()}
	if localVarHttpResponse != nil {
		localVarAPIResponse.Response = localVarHttpResponse.RawResponse
		localVarAPIResponse.Payload = localVarHttpResponse.Body()
	}

	if err != nil {
		return *successPayload, localVarAPIResponse, err
	}
	err = json.Unmarshal(localVarHttpResponse.Body(), &successPayload)
	return *successPayload, localVarAPIResponse, err
}

/**
 * Get the HTML code
 * Retrieve the HTML code of the rendered page. This API call should be used when html&#x3D;1 was specified in the screenshot request. 
 *
 * @param id screenshot ID
 * @return void
 */
func (a ScreenshotApi) ScreenshotHtmlGet(id int32) (*APIResponse, error) {

	var localVarHttpMethod = strings.ToUpper("Get")
	// create path and map variables
	localVarPath := a.Configuration.BasePath + "/screenshot/html"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := make(map[string]string)
	var localVarPostBody interface{}
	var localVarFileName string
	var localVarFileBytes []byte
	// authentication '(apiKeyQuery)' required
	// set key with prefix in query string
	localVarQueryParams["key"] =  a.Configuration.GetAPIKeyWithPrefix("key")
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		localVarHeaderParams[key] = a.Configuration.DefaultHeader[key]
	}
	localVarQueryParams.Add("id", a.Configuration.APIClient.ParameterToString(id, ""))

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"text/html",
		}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
	}
	localVarHttpResponse, err := a.Configuration.APIClient.CallAPI(localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)

	var localVarURL, _ = url.Parse(localVarPath)
	localVarURL.RawQuery = localVarQueryParams.Encode()
	var localVarAPIResponse = &APIResponse{Operation: "ScreenshotHtmlGet", Method: localVarHttpMethod, RequestURL: localVarURL.String()}
	if localVarHttpResponse != nil {
		localVarAPIResponse.Response = localVarHttpResponse.RawResponse
		localVarAPIResponse.Payload = localVarHttpResponse.Body()
	}

	if err != nil {
		return localVarAPIResponse, err
	}
	return localVarAPIResponse, err
}

/**
 * Query screenshot status
 * Once a screenshot has been requested, its status must be checked until it is either \&quot;error\&quot; or \&quot;finished\&quot;.
 *
 * @param id screenshot ID received from /api/v1/screenshot/create
 * @param details level of details about the screenshot and the page
 * @return []Screenshot
 */
func (a ScreenshotApi) ScreenshotInfoGet(id int32, details int32) ([]Screenshot, *APIResponse, error) {

	var localVarHttpMethod = strings.ToUpper("Get")
	// create path and map variables
	localVarPath := a.Configuration.BasePath + "/screenshot/info"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := make(map[string]string)
	var localVarPostBody interface{}
	var localVarFileName string
	var localVarFileBytes []byte
	// authentication '(apiKeyQuery)' required
	// set key with prefix in query string
	localVarQueryParams["key"] =  a.Configuration.GetAPIKeyWithPrefix("key")
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		localVarHeaderParams[key] = a.Configuration.DefaultHeader[key]
	}
	localVarQueryParams.Add("id", a.Configuration.APIClient.ParameterToString(id, ""))
	localVarQueryParams.Add("details", a.Configuration.APIClient.ParameterToString(details, ""))

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
		}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new([]Screenshot)
	localVarHttpResponse, err := a.Configuration.APIClient.CallAPI(localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)

	var localVarURL, _ = url.Parse(localVarPath)
	localVarURL.RawQuery = localVarQueryParams.Encode()
	var localVarAPIResponse = &APIResponse{Operation: "ScreenshotInfoGet", Method: localVarHttpMethod, RequestURL: localVarURL.String()}
	if localVarHttpResponse != nil {
		localVarAPIResponse.Response = localVarHttpResponse.RawResponse
		localVarAPIResponse.Payload = localVarHttpResponse.Body()
	}

	if err != nil {
		return *successPayload, localVarAPIResponse, err
	}
	err = json.Unmarshal(localVarHttpResponse.Body(), &successPayload)
	return *successPayload, localVarAPIResponse, err
}

/**
 * Get information about the last 100 screenshots requested.
 * Get information about the last 100 screenshots requested.
 *
 * @param limit maximum number of screenshots&#39; information to return
 * @param status get list of screenshot in a given status (error, finished, in_process)
 * @return []ScreenshotList
 */
func (a ScreenshotApi) ScreenshotListGet(limit int32, status string) ([]ScreenshotList, *APIResponse, error) {

	var localVarHttpMethod = strings.ToUpper("Get")
	// create path and map variables
	localVarPath := a.Configuration.BasePath + "/screenshot/list"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := make(map[string]string)
	var localVarPostBody interface{}
	var localVarFileName string
	var localVarFileBytes []byte
	// authentication '(apiKeyQuery)' required
	// set key with prefix in query string
	localVarQueryParams["key"] =  a.Configuration.GetAPIKeyWithPrefix("key")
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		localVarHeaderParams[key] = a.Configuration.DefaultHeader[key]
	}
	localVarQueryParams.Add("limit", a.Configuration.APIClient.ParameterToString(limit, ""))
	localVarQueryParams.Add("status", a.Configuration.APIClient.ParameterToString(status, ""))

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
		}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new([]ScreenshotList)
	localVarHttpResponse, err := a.Configuration.APIClient.CallAPI(localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)

	var localVarURL, _ = url.Parse(localVarPath)
	localVarURL.RawQuery = localVarQueryParams.Encode()
	var localVarAPIResponse = &APIResponse{Operation: "ScreenshotListGet", Method: localVarHttpMethod, RequestURL: localVarURL.String()}
	if localVarHttpResponse != nil {
		localVarAPIResponse.Response = localVarHttpResponse.RawResponse
		localVarAPIResponse.Payload = localVarHttpResponse.Body()
	}

	if err != nil {
		return *successPayload, localVarAPIResponse, err
	}
	err = json.Unmarshal(localVarHttpResponse.Body(), &successPayload)
	return *successPayload, localVarAPIResponse, err
}

/**
 * Request multiple screenshots
 * Request multiple screenshots in one API call. The API call accepts all the parameters supported by screenshot/create. You can specify up to 10 URLs and 10 instances for a total of 100 screenshots in one API call. 
 *
 * @param url URL of the page to get a screenshot for. You can specify multiple url parameters (up to 10).
 * @param instanceId instance ID to use. You can specify multiple instance_id parameters (up to 10).
 * @param size screenshot size - \&quot;screen\&quot; (default) or \&quot;page\&quot;
 * @param cache use a previous screenshot (same URL, same instance) if it was done within &lt;cache_value&gt; seconds. The default value is 24hours. Specify cache&#x3D;0 if you want a new screenshot.
 * @param delay number of seconds to wait after the page has loaded. This is used to let JavaScript run longer before taking the screenshot. Use delay&#x3D;0 to take screenshots faster.
 * @param flashDelay number of seconds to wait after the page has loaded if Flash elements are present. Use flash_delay&#x3D;0 to take screenshots faster.
 * @param screenWidth width of the browser window. For desktop browsers only.
 * @param screenHeight height of the browser window. For desktop browsers only. (Note: full-page screenshots can have a height of up to 15,000px)
 * @param priority assign priority to the screenshot (for private instances only)
 * @param referer use a custom referrer header - paid screenshots only
 * @param postData send a POST requests with post_data, useful for filling out forms - paid screenshots only
 * @param cookie set a cookie for the URL requested (see Custom POST Data, Referer and Cookie) Cookies should be separated by a ; - paid screenshots only
 * @param script URL of javascript file to execute after the page load event
 * @param details level of information available with screenshot/info
 * @param html saves the HTML of the rendered page which can be retrieved by the API call screenshot/html. This feature costs *1 credit* per screenshot.
 * @param maxWait maximum number of seconds to wait before triggering the PageLoad event. Note that delay will still be used. (default: 0 &#x3D; disabled)
 * @param headers any custom HTTP headers. (Not supported with Internet Explorer)
 * @param hosting hosting option - s3 or browshot
 * @param hostingHeight maximum height of the thumbnail to host
 * @param hostingWidth maximum height of the thumbnail to host
 * @param hostingScale scale of the thumbnail to host
 * @param hostingBucket S3 bucket to upload the screenshot or thumbnail (required for S3)
 * @param hostingFile file name to use (for S3 only)
 * @param hostingHeaders list of headers to add to the S3 object (for S3 only)
 * @return *ScreenshotList
 */
func (a ScreenshotApi) ScreenshotMultipleGet(url string, instanceId int32, size string, cache int32, delay int32, flashDelay int32, screenWidth int32, screenHeight int32, priority int32, referer string, postData string, cookie string, script string, details int32, html int32, maxWait int32, headers string, hosting string, hostingHeight int32, hostingWidth int32, hostingScale float32, hostingBucket string, hostingFile string, hostingHeaders string) (*ScreenshotList, *APIResponse, error) {

	var localVarHttpMethod = strings.ToUpper("Get")
	// create path and map variables
	localVarPath := a.Configuration.BasePath + "/screenshot/multiple"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := make(map[string]string)
	var localVarPostBody interface{}
	var localVarFileName string
	var localVarFileBytes []byte
	// authentication '(apiKeyQuery)' required
	// set key with prefix in query string
	localVarQueryParams["key"] =  a.Configuration.GetAPIKeyWithPrefix("key")
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		localVarHeaderParams[key] = a.Configuration.DefaultHeader[key]
	}
	localVarQueryParams.Add("url", a.Configuration.APIClient.ParameterToString(url, ""))
	localVarQueryParams.Add("instance_id", a.Configuration.APIClient.ParameterToString(instanceId, ""))
	localVarQueryParams.Add("size", a.Configuration.APIClient.ParameterToString(size, ""))
	localVarQueryParams.Add("cache", a.Configuration.APIClient.ParameterToString(cache, ""))
	localVarQueryParams.Add("delay", a.Configuration.APIClient.ParameterToString(delay, ""))
	localVarQueryParams.Add("flash_delay", a.Configuration.APIClient.ParameterToString(flashDelay, ""))
	localVarQueryParams.Add("screen_width", a.Configuration.APIClient.ParameterToString(screenWidth, ""))
	localVarQueryParams.Add("screen_height", a.Configuration.APIClient.ParameterToString(screenHeight, ""))
	localVarQueryParams.Add("priority", a.Configuration.APIClient.ParameterToString(priority, ""))
	localVarQueryParams.Add("referer", a.Configuration.APIClient.ParameterToString(referer, ""))
	localVarQueryParams.Add("post_data", a.Configuration.APIClient.ParameterToString(postData, ""))
	localVarQueryParams.Add("cookie", a.Configuration.APIClient.ParameterToString(cookie, ""))
	localVarQueryParams.Add("script", a.Configuration.APIClient.ParameterToString(script, ""))
	localVarQueryParams.Add("details", a.Configuration.APIClient.ParameterToString(details, ""))
	localVarQueryParams.Add("html", a.Configuration.APIClient.ParameterToString(html, ""))
	localVarQueryParams.Add("max_wait", a.Configuration.APIClient.ParameterToString(maxWait, ""))
	localVarQueryParams.Add("headers", a.Configuration.APIClient.ParameterToString(headers, ""))
	localVarQueryParams.Add("hosting", a.Configuration.APIClient.ParameterToString(hosting, ""))
	localVarQueryParams.Add("hosting_height", a.Configuration.APIClient.ParameterToString(hostingHeight, ""))
	localVarQueryParams.Add("hosting_width", a.Configuration.APIClient.ParameterToString(hostingWidth, ""))
	localVarQueryParams.Add("hosting_scale", a.Configuration.APIClient.ParameterToString(hostingScale, ""))
	localVarQueryParams.Add("hosting_bucket", a.Configuration.APIClient.ParameterToString(hostingBucket, ""))
	localVarQueryParams.Add("hosting_file", a.Configuration.APIClient.ParameterToString(hostingFile, ""))
	localVarQueryParams.Add("hosting_headers", a.Configuration.APIClient.ParameterToString(hostingHeaders, ""))

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
		}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new(ScreenshotList)
	localVarHttpResponse, err := a.Configuration.APIClient.CallAPI(localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)

	var localVarURL, _ = url.Parse(localVarPath)
	localVarURL.RawQuery = localVarQueryParams.Encode()
	var localVarAPIResponse = &APIResponse{Operation: "ScreenshotMultipleGet", Method: localVarHttpMethod, RequestURL: localVarURL.String()}
	if localVarHttpResponse != nil {
		localVarAPIResponse.Response = localVarHttpResponse.RawResponse
		localVarAPIResponse.Payload = localVarHttpResponse.Body()
	}

	if err != nil {
		return successPayload, localVarAPIResponse, err
	}
	err = json.Unmarshal(localVarHttpResponse.Body(), &successPayload)
	return successPayload, localVarAPIResponse, err
}

/**
 * Search for screenshots of a specific URL.
 * Search for screenshots of a specific URL.
 *
 * @param url look for a string matching the URL requested
 * @param limit maximum number of screenshots&#39; information to return
 * @param status get list of screenshot in a given status (error, finished, in_process)
 * @return []ScreenshotList
 */
func (a ScreenshotApi) ScreenshotSearchGet(url string, limit int32, status string) ([]ScreenshotList, *APIResponse, error) {

	var localVarHttpMethod = strings.ToUpper("Get")
	// create path and map variables
	localVarPath := a.Configuration.BasePath + "/screenshot/search"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := make(map[string]string)
	var localVarPostBody interface{}
	var localVarFileName string
	var localVarFileBytes []byte
	// authentication '(apiKeyQuery)' required
	// set key with prefix in query string
	localVarQueryParams["key"] =  a.Configuration.GetAPIKeyWithPrefix("key")
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		localVarHeaderParams[key] = a.Configuration.DefaultHeader[key]
	}
	localVarQueryParams.Add("url", a.Configuration.APIClient.ParameterToString(url, ""))
	localVarQueryParams.Add("limit", a.Configuration.APIClient.ParameterToString(limit, ""))
	localVarQueryParams.Add("status", a.Configuration.APIClient.ParameterToString(status, ""))

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
		}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new([]ScreenshotList)
	localVarHttpResponse, err := a.Configuration.APIClient.CallAPI(localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)

	var localVarURL, _ = url.Parse(localVarPath)
	localVarURL.RawQuery = localVarQueryParams.Encode()
	var localVarAPIResponse = &APIResponse{Operation: "ScreenshotSearchGet", Method: localVarHttpMethod, RequestURL: localVarURL.String()}
	if localVarHttpResponse != nil {
		localVarAPIResponse.Response = localVarHttpResponse.RawResponse
		localVarAPIResponse.Payload = localVarHttpResponse.Body()
	}

	if err != nil {
		return *successPayload, localVarAPIResponse, err
	}
	err = json.Unmarshal(localVarHttpResponse.Body(), &successPayload)
	return *successPayload, localVarAPIResponse, err
}

/**
 * Share a screenshot
 * You can make your screenshots public, add notes, and share it with your friends and colleagues. Only screenshots which are successfully completed can be shared.n the thumbnail. You can take a 1024x768 screenshot, crop it to 768x768, and get it scaled down to 300x300. 
 *
 * @param id screenshot ID
 * @param note note to add on the sharing page
 * @return []ScreenshotHost
 */
func (a ScreenshotApi) ScreenshotShareGet(id int32, note string) ([]ScreenshotHost, *APIResponse, error) {

	var localVarHttpMethod = strings.ToUpper("Get")
	// create path and map variables
	localVarPath := a.Configuration.BasePath + "/screenshot/share"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := make(map[string]string)
	var localVarPostBody interface{}
	var localVarFileName string
	var localVarFileBytes []byte
	// authentication '(apiKeyQuery)' required
	// set key with prefix in query string
	localVarQueryParams["key"] =  a.Configuration.GetAPIKeyWithPrefix("key")
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		localVarHeaderParams[key] = a.Configuration.DefaultHeader[key]
	}
	localVarQueryParams.Add("id", a.Configuration.APIClient.ParameterToString(id, ""))
	localVarQueryParams.Add("note", a.Configuration.APIClient.ParameterToString(note, ""))

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
		}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new([]ScreenshotHost)
	localVarHttpResponse, err := a.Configuration.APIClient.CallAPI(localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)

	var localVarURL, _ = url.Parse(localVarPath)
	localVarURL.RawQuery = localVarQueryParams.Encode()
	var localVarAPIResponse = &APIResponse{Operation: "ScreenshotShareGet", Method: localVarHttpMethod, RequestURL: localVarURL.String()}
	if localVarHttpResponse != nil {
		localVarAPIResponse.Response = localVarHttpResponse.RawResponse
		localVarAPIResponse.Payload = localVarHttpResponse.Body()
	}

	if err != nil {
		return *successPayload, localVarAPIResponse, err
	}
	err = json.Unmarshal(localVarHttpResponse.Body(), &successPayload)
	return *successPayload, localVarAPIResponse, err
}

/**
 * Retrieve a thumbnail image
 * Unlike the other API calls, this API sends back the thumbnail as a PNG file, not JSON. The HTTP response code indicates whether the screenshot was successful (200), or incomplete (404) or failed (404). If the screenshot failed or is not finished, a default image \&quot;Not found\&quot; is sent.  You can crop your screenshots. The crop is done first, then the thumbnail. You can take a 1024x768 screenshot, crop it to 768x768, and get it scaled down to 300x300. 
 *
 * @param id screenshot ID
 * @param width width of the thumbnail
 * @param height height of the thumbnail
 * @param scale scale of the thumbnail
 * @param zoom zoom 1 to 100 percent
 * @param ratio Use fit to keep the original page ration, and fill to get a thumbnail for the exact width and height.  specified. If you provide both width and height, you need to specify the ratio: fit to keep the original width/height ratio (the thumbnail might be smaller than the specified width and height), or fill to crop the image if necessary.
 * @param left left edge of the area to be cropped
 * @param right right edge of the area to be cropped
 * @param top top edge of the area to be cropped
 * @param bottom bottom edge of the area to be cropped
 * @param format image as PNG or JPEG
 * @param shot get the second or third screenshot if multiple screenshots were requested
 * @param quality JPEG quality factor (for JPEG thumbnails only)
 * @return void
 */
func (a ScreenshotApi) ScreenshotThumbnailGet(id int32, width int32, height int32, scale float64, zoom int32, ratio string, left int32, right int32, top int32, bottom int32, format string, shot int32, quality int32) (*APIResponse, error) {

	var localVarHttpMethod = strings.ToUpper("Get")
	// create path and map variables
	localVarPath := a.Configuration.BasePath + "/screenshot/thumbnail"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := make(map[string]string)
	var localVarPostBody interface{}
	var localVarFileName string
	var localVarFileBytes []byte
	// authentication '(apiKeyQuery)' required
	// set key with prefix in query string
	localVarQueryParams["key"] =  a.Configuration.GetAPIKeyWithPrefix("key")
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		localVarHeaderParams[key] = a.Configuration.DefaultHeader[key]
	}
	localVarQueryParams.Add("id", a.Configuration.APIClient.ParameterToString(id, ""))
	localVarQueryParams.Add("width", a.Configuration.APIClient.ParameterToString(width, ""))
	localVarQueryParams.Add("height", a.Configuration.APIClient.ParameterToString(height, ""))
	localVarQueryParams.Add("scale", a.Configuration.APIClient.ParameterToString(scale, ""))
	localVarQueryParams.Add("zoom", a.Configuration.APIClient.ParameterToString(zoom, ""))
	localVarQueryParams.Add("ratio", a.Configuration.APIClient.ParameterToString(ratio, ""))
	localVarQueryParams.Add("left", a.Configuration.APIClient.ParameterToString(left, ""))
	localVarQueryParams.Add("right", a.Configuration.APIClient.ParameterToString(right, ""))
	localVarQueryParams.Add("top", a.Configuration.APIClient.ParameterToString(top, ""))
	localVarQueryParams.Add("bottom", a.Configuration.APIClient.ParameterToString(bottom, ""))
	localVarQueryParams.Add("format", a.Configuration.APIClient.ParameterToString(format, ""))
	localVarQueryParams.Add("shot", a.Configuration.APIClient.ParameterToString(shot, ""))
	localVarQueryParams.Add("quality", a.Configuration.APIClient.ParameterToString(quality, ""))

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"image/png",
		"image/jpeg",
		}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
	}
	localVarHttpResponse, err := a.Configuration.APIClient.CallAPI(localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)

	var localVarURL, _ = url.Parse(localVarPath)
	localVarURL.RawQuery = localVarQueryParams.Encode()
	var localVarAPIResponse = &APIResponse{Operation: "ScreenshotThumbnailGet", Method: localVarHttpMethod, RequestURL: localVarURL.String()}
	if localVarHttpResponse != nil {
		localVarAPIResponse.Response = localVarHttpResponse.RawResponse
		localVarAPIResponse.Payload = localVarHttpResponse.Body()
	}

	if err != nil {
		return localVarAPIResponse, err
	}
	return localVarAPIResponse, err
}

